[Libreoffice-commits] .: sw/source

Christina Rossmanith crossmanith at kemper.freedesktop.org
Mon Feb 21 00:35:56 PST 2011


 sw/source/ui/app/docstyle.cxx |   14 +++++++-------
 sw/source/ui/app/swmodul1.cxx |    2 +-
 sw/source/ui/app/swmodule.cxx |    4 ++--
 3 files changed, 10 insertions(+), 10 deletions(-)

New commits:
commit 7e35b6dcc0e9178558cf8fd49ee373bbb2899e8e
Author: Christina Rossmanith <ChrRossmanith at web.de>
Date:   Mon Feb 21 09:35:38 2011 +0100

    cleaned some comments

diff --git a/sw/source/ui/app/swmodul1.cxx b/sw/source/ui/app/swmodul1.cxx
index 083327f..d8a3ccc 100644
--- a/sw/source/ui/app/swmodul1.cxx
+++ b/sw/source/ui/app/swmodul1.cxx
@@ -83,7 +83,7 @@ using namespace ::com::sun::star::lang;
 
 void lcl_SetUIPrefs(const SwViewOption* pPref, SwView* pView, ViewShell* pSh )
 {
-    // in FrameSets the actual visibility cat differ from the VewOption's setting
+    // in FrameSets the actual visibility can differ from the ViewOption's setting
     sal_Bool bVScrollChanged = pPref->IsViewVScrollBar() != pSh->GetViewOptions()->IsViewVScrollBar();
     sal_Bool bHScrollChanged = pPref->IsViewHScrollBar() != pSh->GetViewOptions()->IsViewHScrollBar();
     sal_Bool bVAlignChanged = pPref->IsVRulerRight() != pSh->GetViewOptions()->IsVRulerRight();
diff --git a/sw/source/ui/app/swmodule.cxx b/sw/source/ui/app/swmodule.cxx
index 0330cc0..616ad54 100644
--- a/sw/source/ui/app/swmodule.cxx
+++ b/sw/source/ui/app/swmodule.cxx
@@ -201,7 +201,7 @@ SwModule::SwModule( SfxObjectFactory* pWebFact,
 
     pAuthorNames = new SvStringsDtor(5, 1);    // All Redlining-Authors
 
-    //JP 18.10.96: replace SvxAutocorrect with SwAutocorrect
+    // replace SvxAutocorrect with SwAutocorrect
     SvxAutoCorrCfg*    pACfg = SvxAutoCorrCfg::Get();
     if( pACfg )
     {
@@ -268,7 +268,7 @@ void SwModule::CreateLngSvcEvtListener()
 
 void SwDLL::RegisterFactories()
 {
-    // These Id's must not be changed. Trough these Id's the View (resume Documentview)
+    // These Id's must not be changed. Through these Id's the View (resume Documentview)
     // is created by Sfx.
     if ( SvtModuleOptions().IsWriter() )
         SwView::RegisterFactory         ( 2 );


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/ui/app/docstyle.cxx b/sw/source/ui/app/docstyle.cxx
index ef4e640..ffa2f54 100644
--- a/sw/source/ui/app/docstyle.cxx
+++ b/sw/source/ui/app/docstyle.cxx
@@ -68,7 +68,7 @@
 #include <SwRewriter.hxx>
 #include <undobj.hxx>
 
-// MD 06.02.95: The Format names in the list of all names have the
+// The Format names in the list of all names have the
 // following family as their first character:
 
 #define	cCHAR		(sal_Unicode)'c'
@@ -165,7 +165,7 @@ SwCharFmt* lcl_FindCharFmt(	SwDoc& rDoc,
 
 
 /*--------------------------------------------------------------------
-    Description: 	find/create ParaFormate
+    Description: 	find/create ParaFormats
                     fill Style
  --------------------------------------------------------------------*/
 
@@ -246,7 +246,7 @@ SwFrmFmt* lcl_FindFrmFmt(	SwDoc& rDoc,
 }
 
 /*--------------------------------------------------------------------
-    Description:	Site descriptors
+    Description:	Page descriptors
  --------------------------------------------------------------------*/
 
 
@@ -725,7 +725,7 @@ String  SwDocStyleSheet::GetDescription(SfxMapUnit eUnit)
                 }
             pItem = aIter.NextItem();
         }
         // Special treatment for Break, Site template and Site offset
         if(sBreak.Len() && !sModel.Len())  // when Model, break is invalid
         {
             if(aDesc.Len())
@@ -888,7 +888,7 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
 }
 
 /*--------------------------------------------------------------------
-    Description:	hirarchy of deduction
+    Description:	hierarchy of deduction
  --------------------------------------------------------------------*/
 
 
@@ -2114,7 +2114,7 @@ void  SwDocStyleSheetPool::Replace( SfxStyleSheetBase& rSource,
     BOOL bSwSrcPool = GetAppName() == rSource.GetPool().GetAppName();
     if( SFX_STYLE_FAMILY_PAGE == eFamily && bSwSrcPool )
     {
-        // deal with seperately!
+        // deal with separately!
         SwPageDesc* pDestDsc =
             (SwPageDesc*)((SwDocStyleSheet&)rTarget).GetPageDesc();
         SwPageDesc* pCpyDsc =
@@ -2454,7 +2454,7 @@ SfxStyleSheetBase*  SwStyleSheetIterator::First()
             const BOOL  bUsed = bIsSearchUsed && (bOrganizer || rDoc.IsUsed(*pFmt));
             if( !bUsed )
             {
-                // Standard is no User template #46181#
+                // Standard is no User template
                 const USHORT nId = rDoc.GetDfltCharFmt() == pFmt ?
                         USHORT( RES_POOLCHR_INET_NORMAL ):
                                 pFmt->GetPoolFmtId();
@@ -725,7 +725,7 @@ String  SwDocStyleSheet::GetDescription(SfxMapUnit eUnit)
             pItem = aIter.NextItem();
         }
-        // Special treatment for Break, Site template and Site offset
+        // Special treatment for Break, Page template and Site offset
         if(sBreak.Len() && !sModel.Len())  // when Model, break is invalid
         {